# Data

This subdirectory contains the files for the data used in the examples.

To add a new dataset, upload the data files to this directory and update the `README.md` file to include a description of the dataset.

### 1. Quickstarts

Outputs from the `example/quickstart-1.ipynb` and `example/quickstart-2.ipynb` notebooks.

### 2. DeepSeek

The `DeepSeek` directory contains the data used for testing the DeepSeek models. It includes:

- the `data` directory contains the pre- and post-processed data used for the tests. It contains the following files:

  - `llm_responses.csv`: The testing dataset
  - `llm_responses_processed.csv`: The processed dataset resulting from the tests
  - `response_metrics.pkl`: The metrics for the responses generated by the models

- the visualization outputs, which are stored in the `plots` directory.

### 3. LLM FAQ

The `llm_faq` directory contains the data used for testing various LLMs on USC FAQ. It includes:

- the `data` directory contains the pre- and post-processed data used for the tests. It contains the following files:

  - `response_metrics.pkl`: The metrics for the responses generated by the models
  - `faq_responses.csv`: The testing dataset

- the `plots` directory contains the visualization outputs.

### 4. Threshold

The `threshold` directory contains outputs from the `threshold-example.ipynb` file.
